@@ -1,4 +1,5 @@
 import asyncio
+import sys
 import time
 from functools import wraps
 from typing import Any, Callable, List, TypeVar
@@ -39,6 +40,10 @@ async def test_timeout() -> None:
             await long_running_task()
             assert t._loop is asyncio.get_event_loop()
     assert canceled_raised, "CancelledError was not raised"
+    if sys.version_info >= (3, 11):
+        task = asyncio.current_task()
+        assert task is not None
+        assert not task.cancelling()
 
 
 @pytest.mark.asyncio
@@ -47,7 +52,8 @@ async def test_timeout_finish_in_time() -> None:
         await asyncio.sleep(0.01)
         return "done"
 
-    async with timeout(0.1):
+    # timeout should be long enough to work even on slow bisy test boxes
+    async with timeout(0.5):
         resp = await long_running_task()
     assert resp == "done"
 
@@ -143,7 +149,6 @@ async def test_timeout_time() -> None:
 
 @pytest.mark.asyncio
 async def test_outer_coro_is_not_cancelled() -> None:
-
     has_timeout = False
 
     async def outer() -> None:
@@ -158,6 +163,8 @@ async def test_outer_coro_is_not_cancelled() -> None:
     await task
     assert has_timeout
     assert not task.cancelled()
+    if sys.version_info >= (3, 11):
+        assert not task.cancelling()
     assert task.done()
 
 
@@ -179,6 +186,9 @@ async def test_cancel_outer_coro() -> None:
     assert task.done()
 
 
+@pytest.mark.skipif(
+    sys.version_info >= (3, 11), reason="3.11+ has a different implementation"
+)
 @pytest.mark.asyncio
 async def test_timeout_suppress_exception_chain() -> None:
     with pytest.raises(asyncio.TimeoutError) as ctx:
@@ -195,6 +205,30 @@ async def test_timeout_expired() -> None:
     assert cm.expired
 
 
+@pytest.mark.skipif(
+    sys.version_info < (3, 11), reason="Old versions don't support expired method"
+)
+@pytest.mark.asyncio
+async def test_timeout_expired_as_function() -> None:
+    with pytest.raises(asyncio.TimeoutError):
+        async with timeout(0.01) as cm:
+            await asyncio.sleep(10)
+    assert cm.expired()
+
+
+@pytest.mark.skipif(
+    sys.version_info < (3, 11), reason="Old versions don't support expired method"
+)
+@pytest.mark.asyncio
+async def test_timeout_expired_methods() -> None:
+    async with timeout(0.01) as cm:
+        exp = cm.expired()
+        assert not exp
+        assert bool(exp) is False
+        assert str(exp) == "False"
+        assert repr(exp) == "False"
+
+
 @pytest.mark.asyncio
 async def test_timeout_inner_timeout_error() -> None:
     with pytest.raises(asyncio.TimeoutError):
@@ -235,10 +269,10 @@ async def test_timeout_at_not_fired() -> None:
 
 @pytest.mark.asyncio
 async def test_expired_after_rejecting() -> None:
-    t = timeout(10)
-    assert not t.expired
-    t.reject()
-    assert not t.expired
+    async with timeout(10) as t:
+        assert not t.expired
+        t.reject()
+        assert not t.expired
 
 
 @pytest.mark.asyncio
@@ -247,7 +281,10 @@ async def test_reject_finished() -> None:
         await asyncio.sleep(0)
 
     assert not t.expired
-    with pytest.raises(RuntimeError, match="invalid state EXIT"):
+    with pytest.raises(
+        RuntimeError,
+        match="(invalid state EXIT)|(Cannot change state of finished Timeout)",
+    ):
         t.reject()
 
 
@@ -320,7 +357,13 @@ async def test_shift_by_expired() -> None:
     async with timeout(0.001) as cm:
         with pytest.raises(asyncio.CancelledError):
             await asyncio.sleep(10)
-        with pytest.raises(RuntimeError, match="cannot reschedule expired timeout"):
+        with pytest.raises(
+            RuntimeError,
+            match=(
+                "(cannot reschedule expired timeout)|"
+                "(Cannot change state of expiring Timeout)"
+            ),
+        ):
             cm.shift(10)
 
 
@@ -331,7 +374,13 @@ async def test_shift_to_expired() -> None:
     async with timeout_at(t0 + 0.001) as cm:
         with pytest.raises(asyncio.CancelledError):
             await asyncio.sleep(10)
-        with pytest.raises(RuntimeError, match="cannot reschedule expired timeout"):
+        with pytest.raises(
+            RuntimeError,
+            match=(
+                "(cannot reschedule expired timeout)|"
+                "(Cannot change state of expiring Timeout)"
+            ),
+        ):
             cm.update(t0 + 10)
 
 
@@ -340,7 +389,11 @@ async def test_shift_by_after_cm_exit() -> None:
     async with timeout(1) as cm:
         await asyncio.sleep(0)
     with pytest.raises(
-        RuntimeError, match="cannot reschedule after exit from context manager"
+        RuntimeError,
+        match=(
+            "(cannot reschedule after exit from context manager)|"
+            "(Cannot change state of finished Timeout)"
+        ),
     ):
         cm.shift(1)
 
@@ -350,13 +403,8 @@ async def test_enter_twice() -> None:
     async with timeout(10) as t:
         await asyncio.sleep(0)
 
-    with pytest.raises(RuntimeError, match="invalid state EXIT"):
+    with pytest.raises(
+        RuntimeError, match="(invalid state EXIT)|(Timeout has already been entered)"
+    ):
         async with t:
             await asyncio.sleep(0)
-
-
-@pytest.mark.asyncio
-async def test_deprecated_with() -> None:
-    with pytest.warns(DeprecationWarning):
-        with timeout(1):
-            await asyncio.sleep(0)
